<?php

/**
 * Class NewTrustedShopsTrustbadgeController
 */
class NewTrustedShopsTrustbadgeController extends AbstractModuleCenterModuleController
{
    /**
     * @var string
     */
    protected $jsBaseUrl;

    /**
     * @var string
     */
    protected $stylesBaseUrl;

    /**
     * @var
     */
    protected $db;

    /**
     * @var array
     */
    protected $options = [
        'TRUSTEDSHOPS_TRUSTBADGE_CODE_ACTIVE',
        'TRUSTEDSHOPS_TRUSTBADGE_CODE'
    ];

    /**
     * @var array
     */
    protected $errors = [];

    /**
     *
     */
    protected function _init()
    {
        $this->db               = StaticGXCoreLoader::getDatabaseQueryBuilder();
        $this->stylesBaseUrl    = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Styles';
        $this->jsBaseUrl        = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/JavaScript';
        $this->pageTitle        = $this->languageTextManager->get_text('new_trustedshops_title');

        $this->contentView->set_template_dir(DIR_FS_CATALOG . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/');
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionDefault()
    {
        $pageTitle       = new NonEmptyStringType($this->pageTitle);
        $templateData    = MainFactory::create('KeyValueCollection',
            ['config' => $this->_readConfig(), 'errors' => $this->errors]);
        $template        = new ExistingFile(new NonEmptyStringType(DIR_FS_CATALOG
            . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/trustbadge_configuration.html'));

        $assetsArray = [
            MainFactory::create('Asset', $this->stylesBaseUrl . '/trustedshops_overview.css'),
            MainFactory::create('Asset', $this->jsBaseUrl . '/tsAjaxController.js')
        ];

        $assetCollection = MainFactory::create('AssetCollection', $assetsArray);

        $nav = [
            $this->languageTextManager->get_text('new_trustedshops_label_overview')         => './admin.php?do=NewTrustedShopsModuleCenterModule',
            $this->languageTextManager->get_text('new_trustedshops_label_trustbadge')       => '',
            $this->languageTextManager->get_text('new_trustedshops_label_shop_reviews')     => './admin.php?do=NewTrustedShopsShopReview',
            $this->languageTextManager->get_text('new_trustedshops_label_product_reviews')  => './admin.php?do=NewTrustedShopsProductReview',
        ];

        $navCollection = new ContentNavigationCollection($nav);

        return MainFactory::create('AdminLayoutHttpControllerResponse',
            $pageTitle,
            $template,
            $templateData,
            $assetCollection,
            $navCollection);
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionProcess()
    {
        if ($this->_getPostDataCollection()->keyExists('delete_config')) {
            return $this->_deleteConfig();
        }

        if ($this->_validate($this->_getPostDataCollection()->getArray())) {
            $this->_saveConfig($this->_getPostDataCollection()->getArray());
            $GLOBALS['messageStack']->add($this->languageTextManager->get_text('new_trustedshops_save_config_success'),
                'success');
        }

        return $this->actionDefault();
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    protected function _deleteConfig()
    {
        return $this->actionDefault();
    }

    /**
     * @param array $postData
     *
     * @return bool
     */
    protected function _validate(array $postData)
    {
        return 0 === count($this->errors);
    }

    /**
     * @param array $postData
     */
    protected function _saveConfig(array $postData)
    {
        $postData["TRUSTEDSHOPS_TRUSTBADGE_CODE"] = htmlspecialchars($postData["TRUSTEDSHOPS_TRUSTBADGE_CODE"], ENT_NOQUOTES);

       $this->db->query("UPDATE `trustedshops_configuration` SET trustbadge_code='" . $postData["TRUSTEDSHOPS_TRUSTBADGE_CODE"] . "', trustbadge_active='" . $postData['TRUSTEDSHOPS_TRUSTBADGE_CODE_ACTIVE'] . "' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");
    }

    /**
     * @return array
     */
    protected function _readConfig()
    {
        $config = [];

        $locale =  $_SESSION['trustedshops_locale'];
        $result = $this->db->query("SELECT trustbadge_code, trustbadge_active FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale ."'")->result_array();

        $trustedbadgeCode   = $result[0]['trustbadge_code'];
        $trustedbadgeActive = $result[0]['trustbadge_active'];

        $config["TRUSTEDSHOPS_TRUSTBADGE_CODE_ACTIVE"] = $trustedbadgeActive;

        if (isset($trustedbadgeCode) and empty($trustedbadgeCode) === false) {
            $config["TRUSTEDSHOPS_TRUSTBADGE_CODE"] = htmlspecialchars_decode($trustedbadgeCode);
        } else {
            $config["TRUSTEDSHOPS_TRUSTBADGE_CODE"] = '<script async
                data-desktop-y-offset="0"
                data-mobile-y-offset="0"
                data-desktop-disable-reviews="false"
                data-desktop-enable-custom="false"
                data-desktop-position="right"
                data-desktop-custom-width="156"
                data-desktop-enable-fadeout="false"
                data-disable-mobile="false"
                data-disable-trustbadge="false"
                data-mobile-custom-width="156"
                data-mobile-disable-reviews="false"
                data-mobile-enable-custom="false"
                data-mobile-position="right"
                data-mobile-enable-topbar="false"
                src="//widgets.trustedshops.com/js/XXXXXXXXX.js"></script>';

            $this->db->query("UPDATE `trustedshops_configuration` SET trustbadge_code='" . htmlspecialchars($config["TRUSTEDSHOPS_TRUSTBADGE_CODE"]) . "' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");
        }

        return $config;
    }
}
